package com.ruoyi.buyerapi.mapper;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerBill;

/**
 * 系统发票Mapper接口
 * 
 * @author ruoyi
 * @date 2022-09-19
 */
public interface BuyerBillMapper 
{
    /**
     * 查询系统发票
     * 
     * @param id 系统发票主键
     * @return 系统发票
     */
    public BuyerBill selectBuyerBillById(String id);

    /**
     * 查询系统发票列表
     * 
     * @param buyerBill 系统发票
     * @return 系统发票集合
     */
    public List<BuyerBill> selectBuyerBillList(BuyerBill buyerBill);

    /**
     * 查询发票申请数量
     *
     * @return 发票申请数量
     */
    public int selectCountBuyerBillApply();

    /**
     * 新增系统发票
     * 
     * @param buyerBill 系统发票
     * @return 结果
     */
    public int insertBuyerBill(BuyerBill buyerBill);

    /**
     * 修改系统发票
     * 
     * @param buyerBill 系统发票
     * @return 结果
     */
    public int updateBuyerBill(BuyerBill buyerBill);

    /**
     * 删除系统发票
     * 
     * @param id 系统发票主键
     * @return 结果
     */
    public int deleteBuyerBillById(String id);

    /**
     * 批量删除系统发票
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBuyerBillByIds(String[] ids);
}
